LogVariables

Trait LogVariables 

pub trait LogVariables {
    // Required method
    fn log_level(&self) -> &Mutex<LogLevel>;
}

Required Methods

fn log_level(&self) -> &Mutex<LogLevel>

Trait that defines a method for accessing the current log level.

This trait defines a log_level method that returns a reference to a Mutex<LogLevel> that contains the current log level. The log level determines where log messages are written: to the console, to a file, or both. fn log_level(&self) - Returns a reference to a Mutex<LogLevel> that contains the current log level.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl LogVariables for LogVariablesImpl

Implementation of the LogVariables trait for the LogVariablesImpl struct.